Security Advisories (1)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

NAME

Jifty::Plugin::User - Plugin for building user models

DESCRIPTION

This plugin provides a "user" mixin for your application's user model class. Use this plugin if you want to use Jifty's authentication framework.

SEE ALSO

Jifty::Manual::AccessControl, Jifty::Plugin::User::Mixin::Model::User, Jifty::Plugin::Authentication::Password

LICENSE

Jifty is Copyright 2005-2007 Best Practical Solutions, LLC. Jifty is distributed under the same terms as Perl itself.